#ifndef BOOST_SIMD_INCLUDE_FUNCTIONS_IDIVFIX_HPP_INCLUDED
#define BOOST_SIMD_INCLUDE_FUNCTIONS_IDIVFIX_HPP_INCLUDED

#include <boost/simd/arithmetic/include/functions/idivfix.hpp>

#endif
